@@ -1,5 +1,5 @@
 package Domain::PublicSuffix;
-$Domain::PublicSuffix::VERSION = '0.19';
+$Domain::PublicSuffix::VERSION = '0.20';
 use strict;
 use warnings;
 use base 'Class::Accessor::Fast';
@@ -215,7 +215,7 @@ sub get_root_domain {
 		$self->root_domain($suffix);
 	} else {
 		my $root_domain = $domain;
-		$root_domain =~ s/^.*\.(.*?\.$suffix)$/$1/;
+		$root_domain =~ s/^.*\.(.*?\.$suffix)\.?$/$1/;
 		$self->root_domain($root_domain);
 	}
 
